/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: GlobalVar.cpp,v 1.19 2008/05/05 12:43:59 bowkenken Exp $
***************************************************************/

#include "GlobalVar.h"

SelConf gSelConf;

GuiMenu gGuiMenu;
GuiMessage gGuiMessage;
GuiStat gGuiStat;
GuiNum gGuiNum;
GuiInputString gGuiInpStr;
SelMbrGraph *gSelMbrGraph;
WinPos gWinPos[WIN_KIND_MAX_N];

PcgDun gPcgDun;

Key gKey;

MouseMotion gMouseMotion;

long gMapDragBgnX, gMapDragBgnY;

long nCharWidth;
long nCharHeight;
long nMarginX;
long nMarginY;

#ifdef D_WS
WSCbase *gStatLabel[MBR_MAX_N][STAT_WIN_IDX_MAX_N];
#endif // D_WS

#ifdef D_GTK
GtkWidget *gMapWin;

GtkWidget *gMapButtonContExec;

GtkWidget *gMapDrawingArea;
GtkObject *gMapHScrollBarAdjustment;
GtkObject *gMapVScrollBarAdjustment;
GtkWidget *gMapHScrollBar;
GtkWidget *gMapVScrollBar;
#endif // D_GTK

#ifdef D_MFC
volatile bool gFlagInitMfcDone;
bool gFlagExit;
CDir3d g_Dir3d;
#endif // D_MFC
